@@ -1,14 +1,16 @@
 import logging
 import os
+from unittest import mock
 
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import serialization
 from cryptography.hazmat.primitives.asymmetric import rsa
-from dagster import Field, ModeDefinition, execute_solid, solid
-from dagster.seven import get_system_temp_directory, mock
 from dagster_ssh.resources import SSHResource, key_from_str
 from dagster_ssh.resources import ssh_resource as sshresource
 
+from dagster import Field, ModeDefinition, execute_solid, solid
+from dagster.seven import get_system_temp_directory
+
 
 def generate_ssh_key():
     # generate private/public key pair
